#
# spec file for package fs-uae
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fs-uae
Version:        3.1.66
Release:        1.14
Summary:        Amiga emulator with on-screen GUI and online play support
License:        GPL-2.0-or-later
Group:          System/Emulators/Other
URL:            https://fs-uae.net/
Source:         https://fs-uae.net/files/FS-UAE/Stable/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  zip
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(libmpeg2)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(zlib)

%description
FS-UAE is an Amiga emulator based on UAE/WinUAE, with a focus on
emulating games.

Features include emulation of Amiga 500, 1200, 4000, CD32
and CDTV, perfectly smooth scrolling on 50Hz displays, support
for floppy images in ADF and IPF formats, CD-ROM images in ISO
or BIN/CUE format, mounting directories on a machine as Amiga
hard drives, support for Picasso 96 drivers for high-color and
high-resolution Workbench displays, and more.

A unique feature is support for cross-platform online play.
Amiga games can be played against (or with) other users over
a network.

The emulator uses the Amiga emulation code from the
WinUAE project and requires a moderately fast computer with
accelerated graphics (OpenGL) to work. A game pad or joystick is
recommended, but not required (FS-UAE can emulate a joystick
using the cursor keys and right Ctrl/Alt keys).

%prep
%setup -q

%build
%if 0%{?sle_version} == 150000
export CFLAGS="%optflags -fPIC"
export CXXFLAGS="%optflags -fPIC"
%endif
%configure \
%ifarch %{ix86} x86_64
  --enable-jit
%else
  --disable-jit
%endif
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name}
rm -rf %{buildroot}/%{_datadir}/doc
%fdupes %{buildroot}%{_datadir}

%files -f %{name}.lang
%doc ChangeLog README
%license COPYING
%{_bindir}/%{name}
%{_bindir}/%{name}-device-helper
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/mime/packages/%{name}.xml

%changelog
* Fri Jan 21 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.1.66
  * Updated bundled SDL version to 2.0.18
  * Updated controller mappings
- Rename Source0 field to Source
* Fri Dec  3 2021 Martin Hauke <mardnh@gmx.de>
- Redownload source tarball
* Fri Dec  3 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.1.62
  * macOS: Do not simulate right/middle mouse buttons in full keyboard emulation.
  * Potential fix for crash if warning is issued from device helper.
  * Fix mouse grab on startup on macOS.
- Enable JIT on x86 targets only
* Mon Nov 22 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.1.59
  * Support controller_[event] input mapping for matching all controllers.
  * Prefer $HOME/FS-UAE if it exists, otherwise use $DOCUMENTS/FS-UAE.
  * Support joystick_port_[port]_controller_[event] input mapping.
  * Read [guid].fs-uae-controller controller configs.
  * Fixed uaenative_library option.
  * Added lots of game controller configs.
  * Set SDL_HINT_MAC_BACKGROUND_APP in device helper.
* Thu Nov 11 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.1.47
  * Allow screensaver with SDL_VIDEO_ALLOW_SCREENSAVER=1.
- Switch source tarball format to xz
* Mon Oct 11 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.1.35
  * Fix device helper for xinput devices with recent SDL2 versions.
  * Support for multiple mice disabled by default on macOS due to security
    warning. Use option multiple_mice = 1 to enable.
  * Disable expect_version option (no longer synchronized with launcher).
  * Added support for more physical keys (when using rawinput).
  * Compilation fixes for Apple M1 hardware.
  * Netplay desync fixes related to file system (directory hard drives).
  * Better virtual memory reservation algorithm.
  * Option to automatically pause on menu screen [mrsilver76].
  * Use RTLD_DEEPBIND with dlopen on Linux when loading plugins.
  * Changes to how plugins are looked up.
  * Ide patch.
  * SCP floppy image doesn't wrap to revolution #0 cleanly [keirf].
  * Fixed crash in nname_to_aname [PowderedToastMan].
- Drop patches for issues fixed upstream
  + 0001-Work-around-an-incompatibility-with-C-17.patch
* Fri Oct  8 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add upstream patch to fix FTBFS with gcc11
  + 0001-Work-around-an-incompatibility-with-C-17.patch
- Remove workaround to build fs-uae with gcc10 on Tumbleweed
* Sat Jun  5 2021 Martin Hauke <mardnh@gmx.de>
- Use gcc10 for Tumbleweed to workaround build issues
* Sat Apr 25 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.0.5
  * Packaging change to satisfy Apple's changed notarization process (sigh)
* Thu Apr 23 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.0.4
  * Fix compilation of sana2.cpp with GCC 10
  * Fix OpenGL shaders with multiple passes on macOS
  * Updated the GLAD OpenGL loader
* Tue Mar 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.3
  * No Changes, version bump only to have version numbers in sync
    with fs-uae-launcher
* Wed Nov  6 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.0.2
  * No changes
- from version 3.0.1
  * Fix video scaling when restoring from fullscreen on Windows
* Wed Jul  3 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update to version 3.0.0
  * Fixed JIT direct access on modern Linux distributions
  * FS-UAE default is now to show a 692×540 image, not stretched to
    fill screen
  * Built-in configurations for many more game controllers
  * New option whdload_quit_key to gracefully quit slaves
  * Added more shaders (compiled/ported/written by guest.r and
    rsn8887)
  * Updated emulation core from WinUAE 3300b2
  * Several new configuration options (see Changelog for details)
  * Many more smaller fixes and updates (see Changelog for details)
- Drop reproducible.patch, merged upstream
- Compile with "-fPIC" on Leap 15.0, otherwise the build fails
- Remove obsolete %%post/%%postun sections for no longer supported
  distributions
* Mon May  6 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to make zip file creation reproducible
  (boo#1047218, boo#1041090)
* Wed Sep  5 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable JIT for ARM
* Sat Aug 11 2018 jengelh@inai.de
- Don't have description assume a particular user.
* Wed Aug  8 2018 mardnh@gmx.de
- Initial package, version 2.8.3
  based on home:FrodeSolheim:stable/fs-uae
